@@ -1,14 +1,14 @@
 #!/bin/python3
 import asyncio
 
-from canopto.classes.courses import Courses
-from canopto.core.authenticate import authentication_loop
-from canopto.core.config import parse_config_file
-from canopto.core.menu import select_menu
-from canopto.core.web import close_aclient
+from classes.courses import Courses
+from core.authenticate import authentication_loop
+from core.config import parse_config_file
+from core.menu import select_menu
+from core.web import close_aclient
 
 
-# logging.basicConfig(level=logging.INFO)
+# logging.basicConfig(filename='logfile.txt', level=logging.INFO)
 
 
 async def main():
@@ -17,7 +17,7 @@ async def main():
 
     if is_authenticated:
         courses = Courses('student')
-        await courses.refresh()
+        await courses.refresh_list()
 
         await select_menu(courses)
 
