@@ -5,6 +5,7 @@ class MenuOption(Enum):
     DL_ALL = 1,
     DL_FILES = 2,
     DL_VIDEOS = 3,
-    SEL_FOLDER = 4
+    SEL_FOLDER = 4,
     FAQ = 5,
-    QUIT = 6,
+    LOGOUT = 6,
+    QUIT = 7
